summaryrefslogtreecommitdiffstats
path: root/korganizer/kodaymatrix.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/kodaymatrix.cpp')
-rw-r--r--korganizer/kodaymatrix.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/korganizer/kodaymatrix.cpp b/korganizer/kodaymatrix.cpp
index 1ced5338..0e921e44 100644
--- a/korganizer/kodaymatrix.cpp
+++ b/korganizer/kodaymatrix.cpp
@@ -57,7 +57,7 @@
#undef FocusIn
#undef KeyPress
#undef None
-#undef Status
+#undef tqStatus
#endif
// ============================================================================
@@ -214,9 +214,9 @@ void KODayMatrix::recalculateToday()
mDayLabels[ i ] = TQString::number( KOGlobals::self()->calendarSystem()->day( mDays[i] ));
// if today is in the currently displayed month, hilight today
- if ( mDays[ i ].year() == TQDate::currentDate().year() &&
- mDays[ i ].month() == TQDate::currentDate().month() &&
- mDays[ i ].day() == TQDate::currentDate().day() ) {
+ if ( mDays[ i ].year() == TQDate::tqcurrentDate().year() &&
+ mDays[ i ].month() == TQDate::tqcurrentDate().month() &&
+ mDays[ i ].day() == TQDate::tqcurrentDate().day() ) {
mToday = i;
}
}
@@ -386,15 +386,15 @@ void KODayMatrix::mouseReleaseEvent( TQMouseEvent *e )
mSelEnd = mSelInit;
if (tmp != mSelStart) {
mSelStart = tmp;
- repaint();
+ tqrepaint();
}
} else {
mSelStart = mSelInit;
//repaint only if selection has changed
if (tmp != mSelEnd) {
mSelEnd = tmp;
- repaint();
+ tqrepaint();
}
}
@@ -415,15 +415,15 @@ void KODayMatrix::mouseMoveEvent( TQMouseEvent *e )
mSelEnd = mSelInit;
if ( tmp != mSelStart ) {
mSelStart = tmp;
- repaint();
+ tqrepaint();
}
} else {
mSelStart = mSelInit;
//repaint only if selection has changed
if ( tmp != mSelEnd ) {
mSelEnd = tmp;
- repaint();
+ tqrepaint();
}
}
}
@@ -562,9 +562,9 @@ void KODayMatrix::paintEvent( TQPaintEvent * )
int selw, selh;
bool isRTL = KOGlobals::self()->reverseLayout();
- TQColorGroup cg = palette().active();
+ TQColorGroup cg = tqpalette().active();
- p.begin( &pm, this );
+ p.tqbegin( &pm, this );
pm.fill( cg.base() );
// draw topleft frame
@@ -386,15 +386,15 @@ void KODayMatrix::mouseReleaseEvent( TQMouseEvent *e )
} else {
mSelStart = mSelInit;
- //repaint only if selection has changed
+ //tqrepaint only if selection has changed
if (tmp != mSelEnd) {
mSelEnd = tmp;
@@ -415,15 +415,15 @@ void KODayMatrix::mouseMoveEvent( TQMouseEvent *e )
} else {
mSelStart = mSelInit;
- //repaint only if selection has changed
+ //tqrepaint only if selection has changed
if ( tmp != mSelEnd ) {
mSelEnd = tmp;